# TODO

- [ ] Find out why test for random seed fails
  => most likely an error in the test? Re-running the test always outputs the same
- [x] Add print_every parameter (currently printing is pretty expensive...)
- [x] Need to add a proper test for the ask / tell interface

- [ ] Run on diufrd141
  - [ ] Install everything on the machine
  - [ ] Less than 60 blocks
  - [ ] Sequential fitness evaluation
    - [ ] On BW with mujoco?
    - [ ] On one FE?
